@@ -5,10 +5,10 @@ use strict;
 use warnings 'all';
 use Carp;
 
-use Data::Printer::Filter;
+use Data::Printer::Filter qw/filter p/;
 use Term::ANSIColor;
 
-our $VERSION = '0.02';
+our $VERSION = '0.3';
 
 =head1 NAME
 
@@ -16,7 +16,7 @@ Data::Printer::Filter::JSON - pretty-print your decoded JSON structures!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -93,17 +93,26 @@ This module fixes that! :)
 
 L<JSON::XS> and L<JSON::PP> (L<JSON> 2.x), L<JSON::NotString> (L<JSON> 1.x),
 L<JSON::DWIW>, L<JSON::Parser>, L<JSON::SL>, L<Mojo::JSON>, L<boolean> (used by
-L<Pegex::JSON>).
+L<Pegex::JSON>) and L<JSON::JOM>.
+
+=head3 JSON::JOM Caveat
+
+When working with L<JSON::JOM>, make sure you load it B<after> loading L<Data::Printer>.
+This is L<a known bug and B<garu>'s working on it!|https://github.com/garu/Data-Printer/issues/33>.
 
 =head2 Can't Handle
 
-The ouput of any JSON decoded that doesn NOT use a blessed reference for its
+The output of any JSON decoder that does NOT use a blessed reference for its
 booleans, like L<JSON::Syck> or L<JSON::Streaming::Reader>.
 
 =head1 AUTHOR
 
 Nuba Princigalli <nuba@stastu.com>
 
+=head1 CONTRIBUTORS
+
+Tim Heaney <oylensheegul@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2012, Nuba Princigalli <nuba@stastu.com>. All rights reserved.
@@ -117,21 +126,14 @@ terms as the Perl 5 programming language system itself.
 # JSON::NotString is from JSON 1.x
 # boolean is used by Pegex::JSON
 
-for (
-    qw/
-    JSON::DWIW::Boolean
-    JSON::NotString
-    JSON::PP::Boolean
-    JSON::SL::Boolean
-    JSON::XS::Boolean
-    Mojo::JSON::_Bool
-    boolean
-    /
-  )
-{
-    filter "$_" => sub {
+for ( qw/ JSON::DWIW::Boolean JSON::NotString JSON::PP::Boolean JSON::SL::Boolean
+    JSON::XS::Boolean Mojo::JSON::_Bool boolean /)
+  {
+    filter "$_" => 
+      sub {
         my ( $obj, $p ) = @_;
         my $str;
+
         if ( $obj->isa('JSON::NotString') ) {
             $str = $obj->{value};
         }
@@ -151,6 +153,16 @@ for (
       {
         show_repeated => 1,    # handles object reuse
       };
-}
+  };
+
+for ( qw/ JSON::JOM::Value JSON::JOM::Array JSON::JOM::Object /)
+  {
+    filter "$_" => 
+      sub {
+        my ( $obj, $p ) = @_;
+        return p($obj->TO_JSON);
+      };
+  };
+ 
 
 1;
